@@ -30,19 +30,15 @@
  * @see_also: #ClutterGroup
  *
  * #CallyGroup implements the required ATK interfaces of #ClutterGroup
- * In particular it exposes:
- *
- * <itemizedlist>
- *   <listitem><simpara>Each of the Clutter actors contained in the
- *   Group.</simpara></listitem>
- * </itemizedlist>
+ * In particular it exposes each of the Clutter actors contained in the
+ * group.
  */
 
+#include "config.h"
+
 #include "cally-group.h"
 #include "cally-actor-private.h"
 
-static void       cally_group_class_init      (CallyGroupClass *klass);
-static void       cally_group_init            (CallyGroup *group);
 static gint       cally_group_get_n_children  (AtkObject *obj);
 static AtkObject* cally_group_ref_child       (AtkObject *obj,
                                               gint       i);
