@@ -46,6 +46,8 @@ struct _ClutterBackend
   CoglContext *cogl_context;
   GSource *cogl_source;
 
+  CoglOnscreen *dummy_onscreen;
+
   ClutterDeviceManager *device_manager;
 
   cairo_font_options_t *font_options;
@@ -149,6 +151,12 @@ gint32                  _clutter_backend_get_units_serial               (Clutter
 
 PangoDirection          _clutter_backend_get_keymap_direction           (ClutterBackend         *backend);
 
+void                    _clutter_backend_reset_cogl_framebuffer         (ClutterBackend         *backend);
+
+void                    clutter_set_allowed_drivers                     (const char             *drivers);
+
+void                    clutter_try_set_windowing_backend               (const char             *drivers);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_BACKEND_PRIVATE_H__ */
