@@ -29,34 +29,16 @@
  * #ClutterBinLayout is a layout manager which implements the following
  * policy:
  *
- * <itemizedlist>
- *   <listitem><simpara>the preferred size is the maximum preferred size
+ *   - the preferred size is the maximum preferred size
  *   between all the children of the container using the
- *   layout;</simpara></listitem>
- *   <listitem><simpara>each child is allocated in "layers", on on top
- *   of the other;</simpara></listitem>
- *   <listitem><simpara>for each layer there are horizontal and vertical
- *   alignment policies.</simpara></listitem>
- * </itemizedlist>
+ *   layout;
+ *   - each child is allocated in "layers", on on top
+ *   of the other;
+ *   - for each layer there are horizontal and vertical
+ *   alignment policies.
  *
- * <figure id="bin-layout">
- *   <title>Bin layout</title>
- *   <para>The image shows a #ClutterBinLayout with three layers:
- *   a background #ClutterCairoTexture, set to fill on both the X
- *   and Y axis; a #ClutterTexture, set to center on both the X and
- *   Y axis; and a #ClutterRectangle, set to %CLUTTER_BIN_ALIGNMENT_END
- *   on both the X and Y axis.</para>
- *   <graphic fileref="bin-layout.png" format="PNG"/>
- * </figure>
- *
- * <example id="example-clutter-bin-layout">
- *  <title>How to pack actors inside a BinLayout</title>
- *  <programlisting>
- * <xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../examples/bin-layout.c">
- *   <xi:fallback>FIXME: MISSING XINCLUDE CONTENT</xi:fallback>
- * </xi:include>
- *  </programlisting>
- * </example>
+ * The [bin-layout example](https://git.gnome.org/browse/clutter/tree/examples/bin-layout.c?h=clutter-1.18)
+ * shows how to pack actors inside a #ClutterBinLayout.
  *
  * #ClutterBinLayout is available since Clutter 1.2
  */
@@ -324,7 +306,7 @@ clutter_bin_layout_get_preferred_width (ClutterLayoutManager *manager,
     {
       gfloat minimum, natural;
 
-      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
+      if (!clutter_actor_is_visible (child))
         continue;
 
       clutter_actor_get_preferred_width (child, for_height,
@@ -361,7 +343,7 @@ clutter_bin_layout_get_preferred_height (ClutterLayoutManager *manager,
     {
       gfloat minimum, natural;
 
-      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
+      if (!clutter_actor_is_visible (child))
         continue;
 
       clutter_actor_get_preferred_height (child, for_width,
@@ -449,7 +431,7 @@ clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
       gboolean x_fill, y_fill, is_fixed_position_set;
       float fixed_x, fixed_y;
 
-      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
+      if (!clutter_actor_is_visible (child))
         continue;
 
       meta = clutter_layout_manager_get_child_meta (manager,
@@ -489,8 +471,8 @@ clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
       else
         child_alloc.y1 = allocation_y;
 
-      child_alloc.x2 = available_w;
-      child_alloc.y2 = available_h;
+      child_alloc.x2 = allocation_x + available_w;
+      child_alloc.y2 = allocation_y + available_h;
 
       if (clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_HORIZONTAL))
         {
