@@ -47,10 +47,7 @@
  * #ClutterBehaviour implementation it is possible to take the
  * #ClutterBehaviourPath as an example:
  *
- * <figure id="behaviour-path-alpha">
- *   <title>Effects of alpha functions on a path</title>
- *   <graphic fileref="path-alpha-func.png" format="PNG"/>
- * </figure>
+ * ![](path-alpha-func.png)
  *
  * The actors position between the path's end points directly correlates
  * to the #ClutterAlpha's current alpha value driving the behaviour. With
@@ -67,10 +64,10 @@
  *
  * #ClutterBehaviour is available since Clutter 0.2.
  *
- * #ClutterBehaviour and its sub-classes have been deprecated since Clutter
- * 1.6. You should see <link linkend="migrating-ClutterBehaviour">the
- * migration guide</link> for more information on migrating code from using
- * the #ClutterBehaviour API to the animation framework API.
+ * #ClutterBehaviour and its sub-classes have been discouraged sing Clutter
+ * 1.0, and formally deprecated since Clutter 1.6. You should use the
+ * [implicit animation][clutter-actor-animation] support inside #ClutterActor
+ * if you still have code using #ClutterBehaviour.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -88,14 +85,6 @@
 #include "clutter-scriptable.h"
 #include "clutter-script-private.h"
 
-static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
-
-G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ClutterBehaviour,
-                                  clutter_behaviour,
-                                  G_TYPE_OBJECT,
-                                  G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
-                                                         clutter_scriptable_iface_init));
-
 struct _ClutterBehaviourPrivate
 {
   ClutterAlpha *alpha;
@@ -122,10 +111,14 @@ enum {
 
 static guint behave_signals[LAST_SIGNAL] = { 0 };
 
-#define CLUTTER_BEHAVIOUR_GET_PRIVATE(obj)         \
-              (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
-               CLUTTER_TYPE_BEHAVIOUR,             \
-               ClutterBehaviourPrivate))
+static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
+
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ClutterBehaviour,
+                                  clutter_behaviour,
+                                  G_TYPE_OBJECT,
+                                  G_ADD_PRIVATE (ClutterBehaviour)
+                                  G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
+                                                         clutter_scriptable_iface_init))
 
 static gboolean
 clutter_behaviour_parse_custom_node (ClutterScriptable *scriptable,
@@ -291,14 +284,12 @@ clutter_behaviour_class_init (ClutterBehaviourClass *klass)
 		  _clutter_marshal_VOID__OBJECT,
 		  G_TYPE_NONE, 1,
 		  CLUTTER_TYPE_ACTOR);
-
-  g_type_class_add_private (klass, sizeof (ClutterBehaviourPrivate));
 }
 
 static void
 clutter_behaviour_init (ClutterBehaviour *self)
 {
-  self->priv = CLUTTER_BEHAVIOUR_GET_PRIVATE (self);
+  self->priv = clutter_behaviour_get_instance_private (self);
 }
 
 static void
